@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,10 @@ void testing_spmv_batched_bad_arg(const Arguments& arg)
         int64_t      incy        = 1;
         int64_t      batch_count = 2;
 
-        device_vector<T> alpha_d(1), beta_d(1), one_d(1), zero_d(1);
+        DEVICE_MEMCHECK(device_vector<T>, alpha_d, (1));
+        DEVICE_MEMCHECK(device_vector<T>, beta_d, (1));
+        DEVICE_MEMCHECK(device_vector<T>, one_d, (1));
+        DEVICE_MEMCHECK(device_vector<T>, zero_d, (1));
 
         const T alpha_h(1), beta_h(2), one_h(1), zero_h(0);
 
@@ -66,14 +69,10 @@ void testing_spmv_batched_bad_arg(const Arguments& arg)
         }
 
         // Allocate device memory
-        device_batch_matrix<T> dAp(1, rocblas_packed_matrix_size(N), 1, batch_count);
-        device_batch_vector<T> dx(N, incx, batch_count);
-        device_batch_vector<T> dy(N, incy, batch_count);
-
-        // Check device memory allocation
-        CHECK_DEVICE_ALLOCATION(dAp.memcheck());
-        CHECK_DEVICE_ALLOCATION(dx.memcheck());
-        CHECK_DEVICE_ALLOCATION(dy.memcheck());
+        DEVICE_MEMCHECK(
+            device_batch_matrix<T>, dAp, (1, rocblas_packed_matrix_size(N), 1, batch_count));
+        DEVICE_MEMCHECK(device_batch_vector<T>, dx, (N, incx, batch_count));
+        DEVICE_MEMCHECK(device_batch_vector<T>, dy, (N, incy, batch_count));
 
         DAPI_EXPECT(rocblas_status_invalid_handle,
                     rocblas_spmv_batched_fn,
@@ -215,8 +214,8 @@ void testing_spmv_batched(const Arguments& arg)
     int64_t incy        = arg.incy;
     int64_t batch_count = arg.batch_count;
 
-    host_vector<T> h_alpha(1);
-    host_vector<T> h_beta(1);
+    HOST_MEMCHECK(host_vector<T>, h_alpha, (1));
+    HOST_MEMCHECK(host_vector<T>, h_beta, (1));
     h_alpha[0] = arg.get_alpha<T>();
     h_beta[0]  = arg.get_beta<T>();
 
@@ -246,32 +245,19 @@ void testing_spmv_batched(const Arguments& arg)
 
     // Naming: `h` is in CPU (host) memory(eg hAp), `d` is in GPU (device) memory (eg dAp).
     // Allocate host memory
-    host_batch_matrix<T> hA(N, N, N, batch_count);
-    host_batch_matrix<T> hAp(1, rocblas_packed_matrix_size(N), 1, batch_count);
-    host_batch_vector<T> hx(N, incx, batch_count);
-    host_batch_vector<T> hy(N, incy, batch_count);
-    host_batch_vector<T> hy_gold(N, incy, batch_count);
-
-    // Check host memory allocation
-    CHECK_HIP_ERROR(hA.memcheck());
-    CHECK_HIP_ERROR(hAp.memcheck());
-    CHECK_HIP_ERROR(hx.memcheck());
-    CHECK_HIP_ERROR(hy.memcheck());
-    CHECK_HIP_ERROR(hy_gold.memcheck());
+    HOST_MEMCHECK(host_batch_matrix<T>, hA, (N, N, N, batch_count));
+    HOST_MEMCHECK(host_batch_matrix<T>, hAp, (1, rocblas_packed_matrix_size(N), 1, batch_count));
+    HOST_MEMCHECK(host_batch_vector<T>, hx, (N, incx, batch_count));
+    HOST_MEMCHECK(host_batch_vector<T>, hy, (N, incy, batch_count));
+    HOST_MEMCHECK(host_batch_vector<T>, hy_gold, (N, incy, batch_count));
 
     // Allocate device memory
-    device_batch_matrix<T> dAp(1, rocblas_packed_matrix_size(N), 1, batch_count);
-    device_batch_vector<T> dx(N, incx, batch_count);
-    device_batch_vector<T> dy(N, incy, batch_count);
-    device_vector<T>       d_alpha(1);
-    device_vector<T>       d_beta(1);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(dAp.memcheck());
-    CHECK_DEVICE_ALLOCATION(dx.memcheck());
-    CHECK_DEVICE_ALLOCATION(dy.memcheck());
-    CHECK_DEVICE_ALLOCATION(d_alpha.memcheck());
-    CHECK_DEVICE_ALLOCATION(d_beta.memcheck());
+    DEVICE_MEMCHECK(
+        device_batch_matrix<T>, dAp, (1, rocblas_packed_matrix_size(N), 1, batch_count));
+    DEVICE_MEMCHECK(device_batch_vector<T>, dx, (N, incx, batch_count));
+    DEVICE_MEMCHECK(device_batch_vector<T>, dy, (N, incy, batch_count));
+    DEVICE_MEMCHECK(device_vector<T>, d_alpha, (1));
+    DEVICE_MEMCHECK(device_vector<T>, d_beta, (1));
 
     // Initialize data on host memory
     rocblas_init_matrix(
@@ -343,13 +329,13 @@ void testing_spmv_batched(const Arguments& arg)
 
             if(arg.repeatability_check)
             {
-                host_batch_vector<T> hy_copy(N, incy, batch_count);
-                CHECK_HIP_ERROR(hy_copy.memcheck());
+                HOST_MEMCHECK(host_batch_vector<T>, hy_copy, (N, incy, batch_count));
                 CHECK_HIP_ERROR(hy.transfer_from(dy));
 
                 // multi-GPU support
                 int device_id, device_count;
-                CHECK_HIP_ERROR(hipGetDeviceCount(&device_count));
+                CHECK_HIP_ERROR(limit_device_count(device_count, (int)arg.devices));
+
                 for(int dev_id = 0; dev_id < device_count; dev_id++)
                 {
                     CHECK_HIP_ERROR(hipGetDevice(&device_id));
@@ -360,19 +346,13 @@ void testing_spmv_batched(const Arguments& arg)
                     rocblas_local_handle handle_copy{arg};
 
                     // Allocate device memory
-                    device_batch_matrix<T> dAp_copy(
-                        1, rocblas_packed_matrix_size(N), 1, batch_count);
-                    device_batch_vector<T> dx_copy(N, incx, batch_count);
-                    device_batch_vector<T> dy_copy(N, incy, batch_count);
-                    device_vector<T>       d_alpha_copy(1);
-                    device_vector<T>       d_beta_copy(1);
-
-                    // Check device memory allocation
-                    CHECK_DEVICE_ALLOCATION(dAp_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dx_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dy_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(d_alpha_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(d_beta_copy.memcheck());
+                    DEVICE_MEMCHECK(device_batch_matrix<T>,
+                                    dAp_copy,
+                                    (1, rocblas_packed_matrix_size(N), 1, batch_count));
+                    DEVICE_MEMCHECK(device_batch_vector<T>, dx_copy, (N, incx, batch_count));
+                    DEVICE_MEMCHECK(device_batch_vector<T>, dy_copy, (N, incy, batch_count));
+                    DEVICE_MEMCHECK(device_vector<T>, d_alpha_copy, (1));
+                    DEVICE_MEMCHECK(device_vector<T>, d_beta_copy, (1));
 
                     // copy data from CPU to device
                     CHECK_HIP_ERROR(dx_copy.transfer_from(hx));
