@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -25,7 +25,7 @@
 #include "frequency_monitor.hpp"
 #include "testing_common.hpp"
 
-#define DEBUG_PRINT 0
+#include <rocblas/internal/rocblas-beta.h>
 
 /* ============================================================================================ */
 template <typename Ti, typename To, typename Tc>
@@ -59,8 +59,11 @@ void testing_gemm_batched_ex_bad_arg(const Arguments& arg)
         const rocblas_datatype d_type       = rocblas_type2datatype<To>();
         const rocblas_datatype compute_type = rocblas_type2datatype<Tc>();
 
-        device_vector<Tc> alpha_d(1), beta_d(1), zero_d(1);
-        const Tc          alpha_h(1), beta_h(1), zero_h(0);
+        DEVICE_MEMCHECK(device_vector<Tc>, alpha_d, (1));
+        DEVICE_MEMCHECK(device_vector<Tc>, beta_d, (1));
+        DEVICE_MEMCHECK(device_vector<Tc>, zero_d, (1));
+
+        const Tc alpha_h(1), beta_h(1), zero_h(0);
 
         const Tc* alpha = &alpha_h;
         const Tc* beta  = &beta_h;
@@ -90,19 +93,13 @@ void testing_gemm_batched_ex_bad_arg(const Arguments& arg)
         CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, pointer_mode));
 
         // Allocate device memory
-        device_batch_matrix<Ti> dA(A_row, A_col, lda, batch_count);
-        device_batch_matrix<Ti> dB(B_row, B_col, ldb, batch_count);
-        device_batch_matrix<To> dC(M, N, ldc, batch_count);
-        device_batch_matrix<To> dD(M, N, ldd, batch_count);
-
-        // Check device memory allocation
-        CHECK_DEVICE_ALLOCATION(dA.memcheck());
-        CHECK_DEVICE_ALLOCATION(dB.memcheck());
-        CHECK_DEVICE_ALLOCATION(dC.memcheck());
-        CHECK_DEVICE_ALLOCATION(dD.memcheck());
+        DEVICE_MEMCHECK(device_batch_matrix<Ti>, dA, (A_row, A_col, lda, batch_count));
+        DEVICE_MEMCHECK(device_batch_matrix<Ti>, dB, (B_row, B_col, ldb, batch_count));
+        DEVICE_MEMCHECK(device_batch_matrix<To>, dC, (M, N, ldc, batch_count));
+        DEVICE_MEMCHECK(device_batch_matrix<To>, dD, (M, N, ldd, batch_count));
 
         // host
-        host_batch_matrix<To> hC(M, N, ldc, batch_count);
+        HOST_MEMCHECK(host_batch_matrix<To>, hC, (M, N, ldc, batch_count));
         rocblas_seedrand();
         rocblas_init_matrix<To>(
             hC, arg, rocblas_client_beta_sets_nan, rocblas_client_general_matrix);
@@ -233,7 +230,7 @@ dD.ptr_on_device(), d_type, ldd, batch_count, compute_type, algo, solution_index
 }
 
 template <typename Ti, typename To, typename Tc>
-void testing_gemm_batched_ex(const Arguments& arg)
+void testing_gemm_batched_ex_run(const Arguments& arg)
 {
     auto rocblas_gemm_batched_ex_fn
         = arg.api & c_API_FORTRAN ? rocblas_gemm_batched_ex_fortran : rocblas_gemm_batched_ex;
@@ -288,10 +285,10 @@ void testing_gemm_batched_ex(const Arguments& arg)
 #ifdef ROCBLAS_BENCH
     if(rocblas_internal_tensile_debug_skip_launch())
     {
-        device_batch_vector<Ti> dA(1, 1, batch_count);
-        device_batch_vector<Ti> dB(1, 1, batch_count);
-        device_batch_vector<To> dC(1, 1, batch_count);
-        device_batch_vector<To> dD(1, 1, batch_count);
+        DEVICE_MEMCHECK(device_batch_vector<Ti>, dA, (1, 1, batch_count));
+        DEVICE_MEMCHECK(device_batch_vector<Ti>, dB, (1, 1, batch_count));
+        DEVICE_MEMCHECK(device_batch_vector<To>, dC, (1, 1, batch_count));
+        DEVICE_MEMCHECK(device_batch_vector<To>, dD, (1, 1, batch_count));
         // clang-format off
         DAPI_CHECK(rocblas_gemm_batched_ex_fn, (
 				handle, transA, transB, M, N, K, &h_alpha_Tc,
@@ -315,22 +312,13 @@ void testing_gemm_batched_ex(const Arguments& arg)
 
     // Naming: `h` is in CPU (host) memory(eg hA), `d` is in GPU (device) memory (eg dA).
     // Allocate host memory
-    host_batch_matrix<Ti> hA(A_row, A_col, lda, batch_count);
-    host_batch_matrix<Ti> hB(B_row, B_col, ldb, batch_count);
-    host_batch_matrix<To> hC(M, N, ldc, batch_count);
-
-    // Check host memory allocation
-    CHECK_HIP_ERROR(hA.memcheck());
-    CHECK_HIP_ERROR(hB.memcheck());
-    CHECK_HIP_ERROR(hC.memcheck());
+    HOST_MEMCHECK(host_batch_matrix<Ti>, hA, (A_row, A_col, lda, batch_count));
+    HOST_MEMCHECK(host_batch_matrix<Ti>, hB, (B_row, B_col, ldb, batch_count));
+    HOST_MEMCHECK(host_batch_matrix<To>, hC, (M, N, ldc, batch_count));
 
     // Allocate device memory
-    device_vector<Tc> d_alpha_Tc(1);
-    device_vector<Tc> d_beta_Tc(1);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(d_alpha_Tc.memcheck());
-    CHECK_DEVICE_ALLOCATION(d_beta_Tc.memcheck());
+    DEVICE_MEMCHECK(device_vector<Tc>, d_alpha_Tc, (1));
+    DEVICE_MEMCHECK(device_vector<Tc>, d_beta_Tc, (1));
 
     // Initialize data on host memory
     rocblas_init_matrix<Ti>(
@@ -342,21 +330,16 @@ void testing_gemm_batched_ex(const Arguments& arg)
     if(arg.unit_check || arg.norm_check)
     {
         // Allocate device memory
-        device_batch_matrix<Ti> dA(A_row, A_col, lda, batch_count);
-        device_batch_matrix<Ti> dB(B_row, B_col, ldb, batch_count);
+        DEVICE_MEMCHECK(device_batch_matrix<Ti>, dA, (A_row, A_col, lda, batch_count));
+        DEVICE_MEMCHECK(device_batch_matrix<Ti>, dB, (B_row, B_col, ldb, batch_count));
         // if C!=D, allocate C and D normally
         // if C==D, allocate C big enough for the larger of C and D; D points to C
-        device_batch_matrix<To>  dC(M, N, ldc, batch_count);
-        device_batch_matrix<To>  dD    = (arg.outofplace)
-                                             ? device_batch_matrix<To>(M, N, ldd, batch_count)
-                                             : device_batch_matrix<To>(0, 1, 1, 1);
-        device_batch_matrix<To>& dDref = (arg.outofplace) ? dD : dC;
-
-        // Check device memory allocation
-        CHECK_DEVICE_ALLOCATION(dA.memcheck());
-        CHECK_DEVICE_ALLOCATION(dB.memcheck());
-        CHECK_DEVICE_ALLOCATION(dC.memcheck());
+        DEVICE_MEMCHECK(device_batch_matrix<To>, dC, (M, N, ldc, batch_count));
+        device_batch_matrix<To> dD = (arg.outofplace)
+                                         ? device_batch_matrix<To>(M, N, ldd, batch_count)
+                                         : device_batch_matrix<To>(0, 1, 1, 1);
         CHECK_DEVICE_ALLOCATION(dD.memcheck());
+        device_batch_matrix<To>& dDref = (arg.outofplace) ? dD : dC;
 
         // copy data from CPU to device
         CHECK_HIP_ERROR(dA.transfer_from(hA));
@@ -364,14 +347,9 @@ void testing_gemm_batched_ex(const Arguments& arg)
         CHECK_HIP_ERROR(dC.transfer_from(hC));
 
         using To_hpa = std::conditional_t<std::is_same_v<To, rocblas_bfloat16>, float, To>;
-        host_batch_matrix<To>     hD_1(M, N, ldd, batch_count);
-        host_batch_matrix<To>     hD_2(M, N, ldd, batch_count);
-        host_batch_matrix<To_hpa> hD_gold(M, N, ldd, batch_count);
-
-        // Check host memory allocation
-        CHECK_HIP_ERROR(hD_1.memcheck());
-        CHECK_HIP_ERROR(hD_2.memcheck());
-        CHECK_HIP_ERROR(hD_gold.memcheck());
+        HOST_MEMCHECK(host_batch_matrix<To>, hD_1, (M, N, ldd, batch_count));
+        HOST_MEMCHECK(host_batch_matrix<To>, hD_2, (M, N, ldd, batch_count));
+        HOST_MEMCHECK(host_batch_matrix<To_hpa>, hD_gold, (M, N, ldd, batch_count));
 
         // Initialize data on host memory
         for(int64_t b = 0; b < batch_count; b++)
@@ -423,11 +401,11 @@ void testing_gemm_batched_ex(const Arguments& arg)
 
             if(arg.repeatability_check)
             {
-                host_batch_matrix<To> hD_2_copy(M, N, ldd, batch_count);
-                CHECK_HIP_ERROR(hD_2_copy.memcheck());
+                HOST_MEMCHECK(host_batch_matrix<To>, hD_2_copy, (M, N, ldd, batch_count));
                 // multi-GPU support
                 int device_id, device_count;
-                CHECK_HIP_ERROR(hipGetDeviceCount(&device_count));
+                CHECK_HIP_ERROR(limit_device_count(device_count, (int)arg.devices));
+
                 for(int dev_id = 0; dev_id < device_count; dev_id++)
                 {
                     CHECK_HIP_ERROR(hipGetDevice(&device_id));
@@ -438,24 +416,21 @@ void testing_gemm_batched_ex(const Arguments& arg)
                     rocblas_local_handle handle_copy{arg};
 
                     //Allocate device memory in new device
-                    device_batch_matrix<Ti> dA_copy(A_row, A_col, lda, batch_count);
-                    device_batch_matrix<Ti> dB_copy(B_row, B_col, ldb, batch_count);
+                    DEVICE_MEMCHECK(
+                        device_batch_matrix<Ti>, dA_copy, (A_row, A_col, lda, batch_count));
+                    DEVICE_MEMCHECK(
+                        device_batch_matrix<Ti>, dB_copy, (B_row, B_col, ldb, batch_count));
                     // if C!=D, allocate C and D normally
                     // if C==D, allocate C big enough for the larger of C and D; D points to C
-                    device_batch_matrix<To> dC_copy(M, N, ldc, batch_count);
+                    DEVICE_MEMCHECK(device_batch_matrix<To>, dC_copy, (M, N, ldc, batch_count));
                     device_batch_matrix<To> dD_copy
                         = (arg.outofplace) ? device_batch_matrix<To>(M, N, ldd, batch_count)
                                            : device_batch_matrix<To>(0, 1, 1, 1);
+                    CHECK_DEVICE_ALLOCATION(dD_copy.memcheck());
                     device_batch_matrix<To>& dDref_copy = (arg.outofplace) ? dD_copy : dC_copy;
 
-                    device_vector<Tc> d_alpha_Tc_copy(1);
-                    device_vector<Tc> d_beta_Tc_copy(1);
-
-                    // Check device memory allocation
-                    CHECK_DEVICE_ALLOCATION(dA_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dB_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dC_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dD_copy.memcheck());
+                    DEVICE_MEMCHECK(device_vector<Tc>, d_alpha_Tc_copy, (1));
+                    DEVICE_MEMCHECK(device_vector<Tc>, d_beta_Tc_copy, (1));
 
                     // copy data from CPU to device
                     CHECK_HIP_ERROR(dA_copy.transfer_from(hA));
@@ -523,9 +498,7 @@ void testing_gemm_batched_ex(const Arguments& arg)
         {
             if(arg.unit_check)
             {
-                if((rocblas_handle(handle)->getArchMajor() == 11
-                    || rocblas_handle(handle)->getArchMajor() == 12)
-                   && (sizeof(Ti) == 2))
+                if((rocblas_handle(handle)->getArchMajor() == 11) && (sizeof(Ti) == 2))
                 {
                     const double tol = K * sum_error_tolerance_for_gfx11<Tc, Ti, To>;
                     near_check_general<To, To_hpa>(M, N, ldd, hD_gold, hD_1, batch_count, tol);
@@ -553,9 +526,7 @@ void testing_gemm_batched_ex(const Arguments& arg)
         {
             if(arg.unit_check)
             {
-                if((rocblas_handle(handle)->getArchMajor() == 11
-                    || rocblas_handle(handle)->getArchMajor() == 12)
-                   && (sizeof(Ti) == 2))
+                if((rocblas_handle(handle)->getArchMajor() == 11) && (sizeof(Ti) == 2))
                 {
                     const double tol = K * sum_error_tolerance_for_gfx11<Tc, Ti, To>;
                     near_check_general<To, To_hpa>(M, N, ldd, hD_gold, hD_2, batch_count, tol);
@@ -595,21 +566,18 @@ void testing_gemm_batched_ex(const Arguments& arg)
             arg.flush_batch_count, arg.flush_memory_size, a_b_c_cached_size);
 
         // Allocate device memory
-        device_batch_matrix<Ti> dA(A_row, A_col, lda, batch_count * flush_batch_count);
-        device_batch_matrix<Ti> dB(B_row, B_col, ldb, batch_count * flush_batch_count);
+        DEVICE_MEMCHECK(
+            device_batch_matrix<Ti>, dA, (A_row, A_col, lda, batch_count * flush_batch_count));
+        DEVICE_MEMCHECK(
+            device_batch_matrix<Ti>, dB, (B_row, B_col, ldb, batch_count * flush_batch_count));
         // if C!=D, allocate C and D normally
         // if C==D, allocate C big enough for the larger of C and D; D points to C
-        device_batch_matrix<To> dC(M, N, ldc, batch_count * flush_batch_count);
+        DEVICE_MEMCHECK(device_batch_matrix<To>, dC, (M, N, ldc, batch_count * flush_batch_count));
         device_batch_matrix<To> dD
             = (arg.outofplace) ? device_batch_matrix<To>(M, N, ldd, batch_count * flush_batch_count)
                                : device_batch_matrix<To>(0, 1, 1, 1);
-        device_batch_matrix<To>& dDref = (arg.outofplace) ? dD : dC;
-
-        // Check device memory allocation
-        CHECK_DEVICE_ALLOCATION(dA.memcheck());
-        CHECK_DEVICE_ALLOCATION(dB.memcheck());
-        CHECK_DEVICE_ALLOCATION(dC.memcheck());
         CHECK_DEVICE_ALLOCATION(dD.memcheck());
+        device_batch_matrix<To>& dDref = (arg.outofplace) ? dD : dC;
 
         // copy data from CPU to device
         CHECK_HIP_ERROR(dA.broadcast_one_batch_matrix_from(hA));
@@ -620,11 +588,26 @@ void testing_gemm_batched_ex(const Arguments& arg)
 
         CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, rocblas_pointer_mode_host));
 
+        // if solution index is given check it is valid before benchmarking
+        if(algo == rocblas_gemm_algo_solution_index && solution_index != 0)
+        {
+            uint32_t test_flags = flags | rocblas_gemm_flags_check_solution_index;
+            // clang-format off
+            DAPI_CHECK(rocblas_gemm_batched_ex_fn, (
+                                    handle, transA, transB, M, N, K, &h_alpha_Tc,
+                                    dA.ptr_on_device(), arg.a_type, lda,
+                                    dB.ptr_on_device(), arg.b_type, ldb, &h_beta_Tc,
+                                    dC.ptr_on_device(), arg.c_type, ldc,
+                                    dDref.ptr_on_device(),  d_type, ldd,
+                                    batch_count, arg.compute_type, algo, solution_index, test_flags));
+            // clang-format on
+        }
+
         for(int i = 0; i < number_cold_calls; i++)
         {
             // clang-format off
             DAPI_DISPATCH(rocblas_gemm_batched_ex_fn, (
-				    handle, transA, transB, M, N, K, &h_alpha_Tc,
+                                    handle, transA, transB, M, N, K, &h_alpha_Tc,
                                     dA.ptr_on_device(), arg.a_type, lda,
                                     dB.ptr_on_device(), arg.b_type, ldb, &h_beta_Tc,
                                     dC.ptr_on_device(), arg.c_type, ldc,
@@ -675,3 +658,68 @@ void testing_gemm_batched_ex(const Arguments& arg)
                           rocblas_error);
     }
 }
+
+template <typename Ti, typename To, typename Tc>
+void testing_gemm_batched_ex(const Arguments& arg)
+{
+    bool                     compare_solutions = arg.solution_index == -2;
+    const Arguments*         arguments         = &arg;
+    Arguments                run_arg(arg);
+    std::vector<rocblas_int> solutions_that_solve(1, 0);
+
+    rocblas_gemm_algo algo = rocblas_gemm_algo(arg.algo);
+
+#ifdef BUILD_WITH_TENSILE // tensile or hipblaslt only for now
+    if(compare_solutions && algo == rocblas_gemm_algo_solution_index)
+    {
+        arguments = &run_arg; // override
+
+        rocblas_local_handle handle{arg};
+        CHECK_ROCBLAS_ERROR(rocblas_set_pointer_mode(handle, rocblas_pointer_mode_host));
+
+        // fetch all solutions
+        rocblas_int             solution_count = 0;
+        const rocblas_operation transA         = char2rocblas_operation(arg.transA);
+        const rocblas_operation transB         = char2rocblas_operation(arg.transB);
+        if(!arg.outofplace)
+        {
+            run_arg.ldd    = arg.ldc;
+            run_arg.d_type = arg.c_type;
+        }
+
+        Tc h_alpha_Tc = arg.get_alpha<Tc>();
+        Tc h_beta_Tc  = arg.get_beta<Tc>();
+
+#define GEMM_EX_SOL_ARGS                                                                    \
+    handle, transA, transB, arg.M, arg.N, arg.K, &h_alpha_Tc, nullptr, arg.a_type, arg.lda, \
+        nullptr, arg.b_type, arg.ldb, &h_beta_Tc, nullptr, arg.c_type, arg.ldc, nullptr,    \
+        run_arg.d_type, run_arg.ldd, run_arg.batch_count, arg.compute_type, algo
+
+        CHECK_ROCBLAS_ERROR(rocblas_gemm_batched_ex_get_solutions(
+            GEMM_EX_SOL_ARGS, rocblas_gemm_flags_none, nullptr, &solution_count));
+        solutions_that_solve.resize(solution_count);
+        if(solution_count > 0)
+        {
+            CHECK_ROCBLAS_ERROR(rocblas_gemm_batched_ex_get_solutions(GEMM_EX_SOL_ARGS,
+                                                                      rocblas_gemm_flags_none,
+                                                                      solutions_that_solve.data(),
+                                                                      &solution_count));
+
+            // append default
+            solutions_that_solve.push_back(0);
+        }
+    }
+#endif
+
+    for(auto sol : solutions_that_solve)
+    {
+        if(compare_solutions)
+        {
+            run_arg.solution_index = sol;
+        }
+
+        testing_gemm_batched_ex_run<Ti, To, Tc>(*arguments);
+    }
+
+#undef GEMM_EX_SOL_ARGS
+}
