@@ -22,9 +22,11 @@
 
 #pragma once
 
+#include "host_alloc.hpp"
 #include "rocblas.h"
 #include "rocblas_test.hpp"
 #include "singletons.hpp"
+
 #include <cinttypes>
 
 #define MEM_MAX_GUARD_PAD 8192
@@ -35,6 +37,24 @@
 template <typename T>
 void rocblas_init_nan(T* A, size_t N);
 
+template <typename T>
+inline rocblas_stride align_stride(rocblas_stride stride)
+{
+    // hipMalloc aligns pointers on 256 byte boundaries (or a multiple of 256)
+    // this function is to align stride*sizeof(T) on 256 byte boundaries
+    size_t byte_alignment = 256;
+
+    if(byte_alignment % sizeof(T) == 0)
+    {
+        size_t type_alignment = byte_alignment / sizeof(T);
+        return ((stride - 1) / type_alignment + 1) * type_alignment;
+    }
+    else
+    {
+        return ((stride - 1) / byte_alignment + 1) * byte_alignment;
+    }
+}
+
 /* ============================================================================================ */
 /*! \brief  base-class to allocate/deallocate device memory */
 template <typename T>
@@ -88,6 +108,16 @@ public:
     T* device_vector_setup()
     {
         T* d = nullptr;
+
+        if(use_HMM)
+        {
+            if(!host_mem_safe(m_bytes))
+            {
+                // exception same as host_alloc helper, could consider new exception
+                throw std::bad_alloc{};
+            }
+        }
+
         if(use_HMM ? hipMallocManaged(&d, m_bytes) : (hipMalloc)(&d, m_bytes) != hipSuccess)
         {
             rocblas_cerr << "Warning: hip can't allocate " << m_bytes << " bytes ("
@@ -113,6 +143,10 @@ public:
             }
         }
 #endif
+
+        if(use_HMM)
+            alloc_ptr_use(d, m_bytes); // count the same as host memory
+
         return d;
     }
 
@@ -154,6 +188,9 @@ public:
 
             // Free device memory
             CHECK_HIP_ERROR((hipFree)(d));
+
+            if(use_HMM)
+                free_ptr_use(d); // release count
         }
     }
 };
