@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -127,6 +127,14 @@ public:
         return m_stride;
     }
 
+    //!
+    //! @brief Returns nmemb
+    //!
+    rocblas_stride nmemb() const
+    {
+        return m_nmemb;
+    }
+
     //!
     //! @brief Returns pointer.
     //! @param batch_index The batch index.
