@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -77,14 +77,6 @@ namespace
         if(!handle)
             return rocblas_status_invalid_handle;
 
-        if constexpr(std::is_same_v<API_INT, int>)
-        {
-            if(batch_count > c_YZ_grid_launch_limit && handle->isYZGridDim16bit())
-            {
-                return rocblas_status_invalid_size;
-            }
-        }
-
         size_t dev_bytes = rocblas_reduction_workspace_size<API_INT, ROCBLAS_DOT_NB * WIN, T2>(
             n, incx, incy, batch_count);
         if(handle->is_device_memory_size_query())
@@ -95,52 +87,53 @@ namespace
                 return handle->set_optimal_device_memory_size(dev_bytes);
         }
 
-        auto layer_mode     = handle->layer_mode;
-        auto check_numerics = handle->check_numerics;
+        auto                    layer_mode     = handle->layer_mode;
+        auto                    check_numerics = handle->check_numerics;
+        rocblas_internal_logger logger;
         if(layer_mode & rocblas_layer_mode_log_trace)
-            log_trace(handle,
-                      rocblas_dot_strided_batched_name<CONJ, T>,
-                      n,
-                      x,
-                      incx,
-                      stridex,
-                      y,
-                      incy,
-                      stridey,
-                      batch_count);
+            logger.log_trace(handle,
+                             rocblas_dot_strided_batched_name<CONJ, T>,
+                             n,
+                             x,
+                             incx,
+                             stridex,
+                             y,
+                             incy,
+                             stridey,
+                             batch_count);
 
         if(layer_mode & rocblas_layer_mode_log_bench)
-            log_bench(handle,
-                      ROCBLAS_API_BENCH " -f dot_strided_batched -r",
-                      rocblas_precision_string<T>,
-                      "-n",
-                      n,
-                      "--incx",
-                      incx,
-                      "--stride_x",
-                      stridex,
-                      "--incy",
-                      incy,
-                      "--stride_y",
-                      stridey,
-                      "--batch_count",
-                      batch_count);
+            logger.log_bench(handle,
+                             ROCBLAS_API_BENCH " -f dot_strided_batched -r",
+                             rocblas_precision_string<T>,
+                             "-n",
+                             n,
+                             "--incx",
+                             incx,
+                             "--stride_x",
+                             stridex,
+                             "--incy",
+                             incy,
+                             "--stride_y",
+                             stridey,
+                             "--batch_count",
+                             batch_count);
 
         if(layer_mode & rocblas_layer_mode_log_profile)
-            log_profile(handle,
-                        rocblas_dot_strided_batched_name<CONJ, T>,
-                        "N",
-                        n,
-                        "incx",
-                        incx,
-                        "stride_x",
-                        stridex,
-                        "incy",
-                        incy,
-                        "stride_y",
-                        stridey,
-                        "batch_count",
-                        batch_count);
+            logger.log_profile(handle,
+                               rocblas_dot_strided_batched_name<CONJ, T>,
+                               "N",
+                               n,
+                               "incx",
+                               incx,
+                               "stride_x",
+                               stridex,
+                               "incy",
+                               incy,
+                               "stride_y",
+                               stridey,
+                               "batch_count",
+                               batch_count);
 
         // Quick return if possible.
         if(batch_count <= 0)
