@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -53,7 +53,9 @@ rocblas_status rocblas_internal_rotm_launcher(rocblas_handle handle,
     auto shiftx = incx < 0 ? offset_x - ptrdiff_t(incx) * (n - 1) : offset_x;
     auto shifty = incy < 0 ? offset_y - ptrdiff_t(incy) * (n - 1) : offset_y;
 
-    dim3        blocks((n - 1) / NB + 1, batch_count);
+    int batches = handle->getBatchGridDim((int)batch_count);
+
+    dim3        blocks((n - 1) / NB + 1, 1, batches);
     dim3        threads(NB);
     hipStream_t rocblas_stream = handle->get_stream();
 
@@ -74,7 +76,8 @@ rocblas_status rocblas_internal_rotm_launcher(rocblas_handle handle,
                               stride_y,
                               param,
                               offset_param,
-                              stride_param);
+                              stride_param,
+                              batch_count);
     else if(!BATCHED_OR_STRIDED)
         ROCBLAS_LAUNCH_KERNEL((rocblas_rotm_kernel_regular<NB>),
                               blocks,
