@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2019-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2019-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -180,18 +180,24 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
         = arch_major == 10 || arch_major == 11 || arch_major == 12 ? true : false;
 
     bool is_gfx11xx = arch_major == 11 ? true : false;
+    bool is_gfx12xx = arch_major == 12 ? true : false;
     bool is_gfx908  = handle->getArch() == 908 ? true : false;
     bool is_gfx906  = handle->getArch() == 906 ? true : false;
     bool is_gfx90a  = handle->getArch() == 910 ? true : false;
     bool is_gfx942  = handle->getArch() == 942 ? true : false;
 
+    int batches = handle->getBatchGridDim((int)batch_count);
+
     if(transA == rocblas_operation_none)
     {
 #define gemvn_KARGS(alpha_, beta_)                                                             \
     gemvn_grid, gemvn_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, beta_, stride_beta, y, shifty, incy, stridey
+        strideA, x, shiftx, incx, stridex, beta_, stride_beta, y, shifty, incy, stridey,       \
+        batch_count
 
-        if(!i64_incs && is_gfx90a && m <= 32 && n <= 32 && batch_count >= 256)
+        if(!i64_incs && m <= 32 && n <= 32
+           && ((is_gfx90a && batch_count >= gemv_sm_mn_gfx90a_batch_min_threshold)
+               || (is_gfx942 && batch_count >= gemv_sm_mn_gfx942_batch_min_threshold)))
         {
 #define gemvn_sm_mn_batched_KARGS(alpha_, beta_)                                                 \
     gemvn_sm_mn_batched_grid, gemvn_sm_mn_batched_threads, 0, rocblas_stream, m, n, alpha_,      \
@@ -234,7 +240,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
             rocblas_int          blocks      = (m - 1) / (GEMVN_DIM_X * 4) + 1;
             if(std::is_same_v<Tex, rocblas_double_complex>)
                 blocks = (m - 1) / (GEMVN_DIM_X) + 1;
-            dim3 gemvn_grid(blocks, batch_count);
+            dim3 gemvn_grid(blocks, 1, batches);
             dim3 gemvn_threads(GEMVN_DIM_X, GEMVN_DIM_Y);
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
@@ -261,7 +267,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           gemvn_KARGS(*alpha, *beta));
             }
         }
-        //optimized gemvn kernel with double buffered loads for gfx90a.
+        //optimized gemvn kernel with double buffered loads for gfx90a or gfx942
         else if(!i64_incs && is_atomics_allowed && (is_float || is_double) && (m == n)
                 && (m % rocblas_gemv_bx() == 0)
                 && (is_gfx90a
@@ -274,7 +280,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                 // The following rocblas_gemv_scal_kernel does the `y = y*beta` computation
                 static constexpr int NB               = 256;
                 const int            gemv_scal_blocks = (m - 1) / NB + 1;
-                dim3                 grid(gemv_scal_blocks, batch_count);
+                dim3                 grid(gemv_scal_blocks, 1, batches);
                 dim3                 threads(NB);
                 if(handle->pointer_mode == rocblas_pointer_mode_device)
                 {
@@ -289,7 +295,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           y,
                                           shifty,
                                           incy,
-                                          stridey);
+                                          stridey,
+                                          batch_count);
                 }
                 else
                 {
@@ -305,12 +312,13 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                               y,
                                               shifty,
                                               incy,
-                                              stridey);
+                                              stridey,
+                                              batch_count);
                 }
 
 #define gemvn_double_buffered_KARGS(alpha_)                                                    \
     gemvn_grid, gemvn_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, y, shifty, incy, stridey
+        strideA, x, shiftx, incx, stridex, y, shifty, incy, stridey, batch_count
 
                 // The following kernel does the `y += A * x` computation
                 static constexpr int thread_x            = rocblas_gemv_bx();
@@ -320,7 +328,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
 
                 const int block_x = m / thread_x;
                 dim3      gemvn_threads(thread_x, thread_y);
-                dim3      gemvn_grid(block_x, block_y, batch_count);
+                dim3      gemvn_grid(block_x, block_y, batches);
 
                 if(handle->pointer_mode == rocblas_pointer_mode_device)
                 {
@@ -344,9 +352,9 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
             }
 #undef gemvn_double_buffered_KARGS
         }
-        //optimized gemvn kernel with 512 threads/block for gfx906, gfx908, gfx90a, gfx942 and gfx11xx.
-        // When(m < 2*n) should use 512 threads/block for gfx90a, gfx942 and gfx11xx.
-        else if(((is_gfx11xx || is_gfx90a || is_gfx942) && (m < 2 * n))
+        //optimized gemvn kernel with 512 threads/block for gfx906, gfx908, gfx90a, gfx942, gfx11xx and gfx12xx.
+        // When(m < 2*n) should use 512 threads/block for gfx90a, gfx942, gfx11xx and gfx12xx.
+        else if(((is_gfx11xx || is_gfx12xx || is_gfx90a || is_gfx942) && (m < 2 * n))
                 || (is_gfx908
                     && (((is_float || is_double || is_complex_float) && m <= gemvn_gfx908_threshold
                          && n <= gemvn_gfx908_threshold)
@@ -368,7 +376,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
             rocblas_int          blocks      = (m - 1) / (GEMVN_DIM_X * 4) + 1;
             if(std::is_same_v<Tex, rocblas_double_complex>)
                 blocks = (m - 1) / (GEMVN_DIM_X) + 1;
-            dim3 gemvn_grid(blocks, batch_count);
+            dim3 gemvn_grid(blocks, 1, batches);
             dim3 gemvn_threads(GEMVN_DIM_X, GEMVN_DIM_Y);
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
@@ -403,7 +411,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
             rocblas_int          blocks      = (m - 1) / (GEMVN_DIM_X * 4) + 1;
             if(std::is_same_v<Tex, rocblas_double_complex>)
                 blocks = (m - 1) / (GEMVN_DIM_X) + 1;
-            dim3 gemvn_grid(blocks, batch_count);
+            dim3 gemvn_grid(blocks, 1, batches);
             dim3 gemvn_threads(GEMVN_DIM_X, GEMVN_DIM_Y);
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
@@ -504,12 +512,12 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
             static constexpr int NB     = rocblas_gemvt_sn_NB();
             static constexpr int WIN    = rocblas_gemvt_sn_WIN();
             int                  blocks = rocblas_gemvt_sn_kernel_block_count(m);
-            dim3                 gemvt_grid(blocks, batch_count);
+            dim3                 gemvt_grid(blocks, 1, batches);
             dim3                 gemvt_threads(NB);
 
 #define gemvt_sn_KARGS(alpha_)                                                                 \
     gemvt_grid, gemvt_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, (Tex*)workspace
+        strideA, x, shiftx, incx, stridex, (Tex*)workspace, batch_count
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
             {
@@ -521,7 +529,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           gemvt_sn_KARGS(alpha));
 
                 ROCBLAS_LAUNCH_KERNEL((rocblas_gemvt_sn_reduce<NB, 8>),
-                                      dim3(1, n, batch_count),
+                                      dim3(1, n, batches),
                                       gemvt_threads,
                                       0,
                                       rocblas_stream,
@@ -532,7 +540,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                       shifty,
                                       incy,
                                       stridey,
-                                      (Tex*)workspace);
+                                      (Tex*)workspace,
+                                      batch_count);
             }
             else
             {
@@ -547,7 +556,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           gemvt_sn_KARGS(*alpha));
 
                 ROCBLAS_LAUNCH_KERNEL((rocblas_gemvt_sn_reduce<NB, 8>),
-                                      dim3(1, n, batch_count),
+                                      dim3(1, n, batches),
                                       gemvt_threads,
                                       0,
                                       rocblas_stream,
@@ -558,23 +567,27 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                       shifty,
                                       incy,
                                       stridey,
-                                      workspace);
+                                      workspace,
+                                      batch_count);
             }
 
 #undef gemvt_sn_KARGS
         }
-        //optimized gemvt kernel with double buffered loads for gfx908.
+        //optimized gemvt kernel with double buffered loads for gfx908 and gfx942.
         else if(!i64_incs && is_atomics_allowed && (m == n) && (m % rocblas_gemv_bx() == 0)
-                && (is_gfx908
-                    && ((is_float && m > sgemvt_gfx908_lower_threshold)
-                        || (is_double && m > dgemvt_gfx908_lower_threshold))))
+                && ((is_gfx908
+                     && ((is_float && m > sgemvt_gfx908_lower_threshold)
+                         || (is_double && m > dgemvt_gfx908_lower_threshold)))
+                    || (is_gfx942
+                        && ((is_float && m > gemvt_threshold)
+                            || (is_double && m > gemvt_threshold)))))
         {
             if constexpr(is_float || is_double)
             {
                 // The following rocblas_gemv_scal_kernel does the `y = y*beta` computation
                 static constexpr int NB               = 256;
                 const int            gemv_scal_blocks = (n - 1) / NB + 1;
-                dim3                 grid(gemv_scal_blocks, batch_count);
+                dim3                 grid(gemv_scal_blocks, 1, batches);
                 dim3                 threads(NB);
                 if(handle->pointer_mode == rocblas_pointer_mode_device)
                 {
@@ -589,7 +602,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           y,
                                           shifty,
                                           incy,
-                                          stridey);
+                                          stridey,
+                                          batch_count);
                 }
                 else
                 {
@@ -605,7 +619,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                               y,
                                               shifty,
                                               incy,
-                                              stridey);
+                                              stridey,
+                                              batch_count);
                 }
                 // The following kernel does the `y += A * x` computation
                 static constexpr int thread_x            = rocblas_gemv_bx();
@@ -615,11 +630,11 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
 
                 const int block_x = n / thread_x;
                 dim3      gemvt_threads(thread_x, thread_y);
-                dim3      gemvt_grid(block_x, block_y, batch_count);
+                dim3      gemvt_grid(block_x, block_y, batches);
 
 #define gemvt_double_buffered_KARGS(alpha_)                                                    \
     gemvt_grid, gemvt_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, y, shifty, incy, stridey
+        strideA, x, shiftx, incx, stridex, y, shifty, incy, stridey, batch_count
 
                 if(handle->pointer_mode == rocblas_pointer_mode_device)
                 {
@@ -648,18 +663,19 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
 
 #define gemvt_KARGS(alpha_, beta_)                                                             \
     gemvt_grid, gemvt_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, beta_, stride_beta, y, shifty, incy, stridey
+        strideA, x, shiftx, incx, stridex, beta_, stride_beta, y, shifty, incy, stridey,       \
+        batch_count
 
         //Using kernel code with warp reduction for gfx1030.
         else if(is_arch_10_or_11_or_12
                 && (is_double || is_complex_float
                     || (is_float
-                        && (m < sgemvt_gfx_arch_10_11_threshold
-                            || n < sgemvt_gfx_arch_10_11_threshold))))
+                        && (m < sgemvt_gfx_arch_10_11_12_threshold
+                            || n < sgemvt_gfx_arch_10_11_12_threshold))))
         {
             //Number of threads per block
             static constexpr int NB = 256;
-            dim3                 gemvt_grid(n, batch_count);
+            dim3                 gemvt_grid(n, 1, batches);
             dim3                 gemvt_threads(NB);
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
@@ -691,7 +707,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
         {
             //Number of threads per block
             static constexpr int NB = 256;
-            dim3                 gemvt_grid(n, batch_count);
+            dim3                 gemvt_grid(n, 1, batches);
             dim3                 gemvt_threads(NB);
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
@@ -713,7 +729,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
         {
             //Number of threads per block
             static constexpr int NB = 1024;
-            dim3                 gemvt_grid(n, batch_count);
+            dim3                 gemvt_grid(n, 1, batches);
             dim3                 gemvt_threads(NB);
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
@@ -813,12 +829,12 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
             static constexpr int NB     = rocblas_gemvt_sn_NB();
             static constexpr int WIN    = rocblas_gemvt_sn_WIN();
             int                  blocks = rocblas_gemvt_sn_kernel_block_count(m);
-            dim3                 gemvt_grid(blocks, batch_count);
+            dim3                 gemvt_grid(blocks, 1, batches);
             dim3                 gemvt_threads(NB);
 
 #define gemvt_sn_KARGS(alpha_)                                                                 \
     gemvt_grid, gemvt_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, (Tex*)workspace
+        strideA, x, shiftx, incx, stridex, (Tex*)workspace, batch_count
 
             if(handle->pointer_mode == rocblas_pointer_mode_device)
             {
@@ -830,7 +846,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           gemvt_sn_KARGS(alpha));
 
                 ROCBLAS_LAUNCH_KERNEL((rocblas_gemvt_sn_reduce<NB, 8>),
-                                      dim3(1, n, batch_count),
+                                      dim3(1, n, batches),
                                       gemvt_threads,
                                       0,
                                       rocblas_stream,
@@ -841,7 +857,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                       shifty,
                                       incy,
                                       stridey,
-                                      (Tex*)workspace);
+                                      (Tex*)workspace,
+                                      batch_count);
             }
             else
             {
@@ -856,7 +873,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           gemvt_sn_KARGS(*alpha));
 
                 ROCBLAS_LAUNCH_KERNEL((rocblas_gemvt_sn_reduce<NB, 8>),
-                                      dim3(1, n, batch_count),
+                                      dim3(1, n, batches),
                                       gemvt_threads,
                                       0,
                                       rocblas_stream,
@@ -867,7 +884,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                       shifty,
                                       incy,
                                       stridey,
-                                      workspace);
+                                      workspace,
+                                      batch_count);
             }
 
 #undef gemvt_sn_KARGS
@@ -883,7 +901,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                 // The following rocblas_gemv_scal_kernel does the `y = y*beta` computation
                 static constexpr int NB               = 256;
                 const int            gemv_scal_blocks = (n - 1) / NB + 1;
-                dim3                 grid(gemv_scal_blocks, batch_count);
+                dim3                 grid(gemv_scal_blocks, 1, batches);
                 dim3                 threads(NB);
                 if(handle->pointer_mode == rocblas_pointer_mode_device)
                 {
@@ -898,7 +916,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                           y,
                                           shifty,
                                           incy,
-                                          stridey);
+                                          stridey,
+                                          batch_count);
                 }
                 else
                 {
@@ -914,7 +933,8 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
                                               y,
                                               shifty,
                                               incy,
-                                              stridey);
+                                              stridey,
+                                              batch_count);
                 }
                 // The following kernel does the `y += A * x` computation
                 static constexpr int thread_x            = rocblas_gemv_bx();
@@ -924,11 +944,11 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
 
                 const int block_x = n / thread_x;
                 dim3      gemvt_threads(thread_x, thread_y);
-                dim3      gemvt_grid(block_x, block_y, batch_count);
+                dim3      gemvt_grid(block_x, block_y, batches);
 
 #define gemvt_double_buffered_KARGS(alpha_)                                                    \
     gemvt_grid, gemvt_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, y, shifty, incy, stridey
+        strideA, x, shiftx, incx, stridex, y, shifty, incy, stridey, batch_count
 
                 if(handle->pointer_mode == rocblas_pointer_mode_device)
                 {
@@ -957,13 +977,14 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
 
 #define gemvt_KARGS(alpha_, beta_)                                                             \
     gemvt_grid, gemvt_threads, 0, rocblas_stream, m, n, alpha_, stride_alpha, A, offseta, lda, \
-        strideA, x, shiftx, incx, stridex, beta_, stride_beta, y, shifty, incy, stridey
+        strideA, x, shiftx, incx, stridex, beta_, stride_beta, y, shifty, incy, stridey,       \
+        batch_count
         //Using kernel code with shared memory reduction for single precision and all other precision when m or n is less than 6000.
         else if(!i64_incs && (is_float || m < 6000 || n < 6000))
         {
             //Number of threads per block
             static constexpr int NB = 256;
-            dim3                 gemvt_grid(n, batch_count);
+            dim3                 gemvt_grid(n, 1, batches);
             dim3                 gemvt_threads(NB);
             if(handle->pointer_mode == rocblas_pointer_mode_device)
             {
@@ -983,7 +1004,7 @@ rocblas_status rocblas_internal_gemv_launcher(rocblas_handle    handle,
         {
             //Number of threads per block
             static constexpr int NB = 1024;
-            dim3                 gemvt_grid(n, batch_count);
+            dim3                 gemvt_grid(n, 1, batches);
             dim3                 gemvt_threads(NB);
             if(handle->pointer_mode == rocblas_pointer_mode_device)
             {
