@@ -38,14 +38,6 @@ inline rocblas_status rocblas_tpmv_arg_check(rocblas_handle    handle,
                                              API_INT           batch_count,
                                              size_t&           dev_bytes)
 {
-    if constexpr(std::is_same_v<API_INT, int>)
-    {
-        if(batch_count > c_YZ_grid_launch_limit && handle->isYZGridDim16bit())
-        {
-            return rocblas_status_invalid_size;
-        }
-    }
-
     if(uplo != rocblas_fill_lower && uplo != rocblas_fill_upper)
         return rocblas_status_invalid_value;
 
