@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -64,8 +64,9 @@ namespace
 
         RETURN_ZERO_DEVICE_MEMORY_SIZE_IF_QUERIED(handle);
 
-        auto layer_mode     = handle->layer_mode;
-        auto check_numerics = handle->check_numerics;
+        auto                    layer_mode     = handle->layer_mode;
+        auto                    check_numerics = handle->check_numerics;
+        rocblas_internal_logger logger;
         if(layer_mode
            & (rocblas_layer_mode_log_trace | rocblas_layer_mode_log_bench
               | rocblas_layer_mode_log_profile))
@@ -74,79 +75,79 @@ namespace
             auto side_letter = rocblas_side_letter(side);
 
             if(layer_mode & rocblas_layer_mode_log_trace)
-                log_trace(handle,
-                          rocblas_symm_name<T>,
-                          side,
-                          uplo,
-                          m,
-                          n,
-                          LOG_TRACE_SCALAR_VALUE(handle, alpha),
-                          A,
-                          lda,
-                          stride_a,
-                          B,
-                          ldb,
-                          stride_b,
-                          LOG_TRACE_SCALAR_VALUE(handle, beta),
-                          C,
-                          ldc,
-                          stride_c,
-                          batch_count);
+                logger.log_trace(handle,
+                                 rocblas_symm_name<T>,
+                                 side,
+                                 uplo,
+                                 m,
+                                 n,
+                                 LOG_TRACE_SCALAR_VALUE(handle, alpha),
+                                 A,
+                                 lda,
+                                 stride_a,
+                                 B,
+                                 ldb,
+                                 stride_b,
+                                 LOG_TRACE_SCALAR_VALUE(handle, beta),
+                                 C,
+                                 ldc,
+                                 stride_c,
+                                 batch_count);
 
             if(layer_mode & rocblas_layer_mode_log_bench)
-                log_bench(handle,
-                          ROCBLAS_API_BENCH " -f symm_strided_batched -r",
-                          rocblas_precision_string<T>,
-                          "--side",
-                          side_letter,
-                          "--uplo",
-                          uplo_letter,
-                          "-m",
-                          m,
-                          "-n",
-                          n,
-                          LOG_BENCH_SCALAR_VALUE(handle, alpha),
-                          "--lda",
-                          lda,
-                          "--stride_a",
-                          stride_a,
-                          "--ldb",
-                          ldb,
-                          "--stride_b",
-                          stride_b,
-                          LOG_BENCH_SCALAR_VALUE(handle, beta),
-                          "--ldc",
-                          ldc,
-                          "--stride_c",
-                          stride_c,
-                          "--batch_count",
-                          batch_count);
+                logger.log_bench(handle,
+                                 ROCBLAS_API_BENCH " -f symm_strided_batched -r",
+                                 rocblas_precision_string<T>,
+                                 "--side",
+                                 side_letter,
+                                 "--uplo",
+                                 uplo_letter,
+                                 "-m",
+                                 m,
+                                 "-n",
+                                 n,
+                                 LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                                 "--lda",
+                                 lda,
+                                 "--stride_a",
+                                 stride_a,
+                                 "--ldb",
+                                 ldb,
+                                 "--stride_b",
+                                 stride_b,
+                                 LOG_BENCH_SCALAR_VALUE(handle, beta),
+                                 "--ldc",
+                                 ldc,
+                                 "--stride_c",
+                                 stride_c,
+                                 "--batch_count",
+                                 batch_count);
 
             if(layer_mode & rocblas_layer_mode_log_profile)
-                log_profile(handle,
-                            rocblas_symm_name<T>,
-                            "side",
-                            side_letter,
-                            "uplo",
-                            uplo_letter,
-                            "M",
-                            m,
-                            "N",
-                            n,
-                            "lda",
-                            lda,
-                            "stride_a",
-                            stride_a,
-                            "ldb",
-                            ldb,
-                            "stride_b",
-                            stride_b,
-                            "ldc",
-                            ldc,
-                            "stride_c",
-                            stride_c,
-                            "batch_count",
-                            batch_count);
+                logger.log_profile(handle,
+                                   rocblas_symm_name<T>,
+                                   "side",
+                                   side_letter,
+                                   "uplo",
+                                   uplo_letter,
+                                   "M",
+                                   m,
+                                   "N",
+                                   n,
+                                   "lda",
+                                   lda,
+                                   "stride_a",
+                                   stride_a,
+                                   "ldb",
+                                   ldb,
+                                   "stride_b",
+                                   stride_b,
+                                   "ldc",
+                                   ldc,
+                                   "stride_c",
+                                   stride_c,
+                                   "batch_count",
+                                   batch_count);
         }
 
         static constexpr rocblas_stride offset_C = 0, offset_A = 0, offset_B = 0;
