@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -64,28 +64,29 @@ namespace
             return handle->set_optimal_device_memory_size(size, sizep);
         }
 
-        auto layer_mode     = handle->layer_mode;
-        auto check_numerics = handle->check_numerics;
+        auto                    layer_mode     = handle->layer_mode;
+        auto                    check_numerics = handle->check_numerics;
+        rocblas_internal_logger logger;
 
         if(layer_mode & rocblas_layer_mode_log_trace)
-            log_trace(
+            logger.log_trace(
                 handle, rocblas_trtri_name<T>, uplo, diag, n, A, lda, invA, ldinvA, batch_count);
 
         if(layer_mode & rocblas_layer_mode_log_profile)
-            log_profile(handle,
-                        rocblas_trtri_name<T>,
-                        "uplo",
-                        rocblas_fill_letter(uplo),
-                        "diag",
-                        rocblas_diag_letter(diag),
-                        "N",
-                        n,
-                        "lda",
-                        lda,
-                        "ldinvA",
-                        ldinvA,
-                        "batch_count",
-                        batch_count);
+            logger.log_profile(handle,
+                               rocblas_trtri_name<T>,
+                               "uplo",
+                               rocblas_fill_letter(uplo),
+                               "diag",
+                               rocblas_diag_letter(diag),
+                               "N",
+                               n,
+                               "lda",
+                               lda,
+                               "ldinvA",
+                               ldinvA,
+                               "batch_count",
+                               batch_count);
 
         rocblas_status arg_status
             = rocblas_trtri_arg_check(handle, uplo, diag, n, A, lda, invA, ldinvA, batch_count);
