@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -58,7 +58,8 @@ namespace
                 return handle->set_optimal_device_memory_size(dev_bytes);
         }
 
-        auto layer_mode = handle->layer_mode;
+        auto                    layer_mode = handle->layer_mode;
+        rocblas_internal_logger logger;
         if(layer_mode
            & (rocblas_layer_mode_log_trace | rocblas_layer_mode_log_bench
               | rocblas_layer_mode_log_profile))
@@ -70,58 +71,58 @@ namespace
 
             if(layer_mode & rocblas_layer_mode_log_trace)
             {
-                log_trace(handle,
-                          name,
-                          n,
-                          x,
-                          x_type_str,
-                          incx,
-                          y,
-                          y_type_str,
-                          incy,
-                          result_type_str,
-                          ex_type_str);
+                logger.log_trace(handle,
+                                 name,
+                                 n,
+                                 x,
+                                 x_type_str,
+                                 incx,
+                                 y,
+                                 y_type_str,
+                                 incy,
+                                 result_type_str,
+                                 ex_type_str);
             }
 
             if(layer_mode & rocblas_layer_mode_log_bench)
             {
-                log_bench(handle,
-                          ROCBLAS_API_BENCH " -f",
-                          bench_name,
-                          "-n",
-                          n,
-                          "--a_type",
-                          x_type_str,
-                          "--incx",
-                          incx,
-                          "--b_type",
-                          y_type_str,
-                          "--incy",
-                          incy,
-                          "--c_type",
-                          result_type_str,
-                          "--compute_type",
-                          ex_type_str);
+                logger.log_bench(handle,
+                                 ROCBLAS_API_BENCH " -f",
+                                 bench_name,
+                                 "-n",
+                                 n,
+                                 "--a_type",
+                                 x_type_str,
+                                 "--incx",
+                                 incx,
+                                 "--b_type",
+                                 y_type_str,
+                                 "--incy",
+                                 incy,
+                                 "--c_type",
+                                 result_type_str,
+                                 "--compute_type",
+                                 ex_type_str);
             }
 
             if(layer_mode & rocblas_layer_mode_log_profile)
             {
-                log_profile(handle,
-                            name,
-                            "N",
-                            n,
-                            "a_type",
-                            x_type_str,
-                            "incx",
-                            incx,
-                            "b_type",
-                            y_type_str,
-                            "incy",
-                            incy,
-                            "c_type",
-                            result_type_str,
-                            "compute_type",
-                            ex_type_str);
+                logger.log_profile(handle,
+                                   name,
+                                   "N",
+                                   n,
+                                   "a_type",
+                                   x_type_str,
+                                   "incx",
+                                   incx,
+                                   "b_type",
+                                   y_type_str,
+                                   "incy",
+                                   incy,
+                                   "c_type",
+                                   result_type_str,
+                                   "compute_type",
+                                   ex_type_str);
             }
         }
 
