@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -70,7 +70,7 @@ namespace
         RETURN_IF_ROCBLAS_ERROR(rocblas_copy_alpha_beta_to_host_if_on_device(
             handle, alpha, beta, alpha_h, beta_h, k, compute_type));
         auto saved_pointer_mode = handle->push_pointer_mode(rocblas_pointer_mode_host);
-
+        rocblas_internal_logger logger;
         // If this is a solution fitness query (internal testing), bypass logging and error checks
         if(!handle->get_solution_fitness_query())
         {
@@ -97,127 +97,123 @@ namespace
                     if(layer_mode & rocblas_layer_mode_log_trace)
                     {
                         rocblas_internal_ostream alphass, betass;
-                        if(log_trace_alpha_beta_ex(compute_type, alpha, beta, alphass, betass)
-                           == rocblas_status_success)
-                        {
-                            log_trace(handle,
-                                      ROCBLAS_API_STR(rocblas_gemm_ex),
-                                      trans_a,
-                                      trans_b,
-                                      m,
-                                      n,
-                                      k,
-                                      alphass.str(),
-                                      a,
-                                      a_type_string,
-                                      lda,
-                                      b,
-                                      b_type_string,
-                                      ldb,
-                                      betass.str(),
-                                      c,
-                                      c_type_string,
-                                      ldc,
-                                      d,
-                                      d_type_string,
-                                      ldd,
-                                      compute_type_string,
-                                      algo,
-                                      solution_index,
-                                      rocblas_gemm_flags(flags));
-                        }
+                        (void)rocblas_internal_log_trace_alpha_beta_ex(
+                            compute_type, alpha, beta, alphass, betass);
+                        logger.log_trace(handle,
+                                         ROCBLAS_API_STR(rocblas_gemm_ex),
+                                         trans_a,
+                                         trans_b,
+                                         m,
+                                         n,
+                                         k,
+                                         alphass.str(),
+                                         a,
+                                         a_type_string,
+                                         lda,
+                                         b,
+                                         b_type_string,
+                                         ldb,
+                                         betass.str(),
+                                         c,
+                                         c_type_string,
+                                         ldc,
+                                         d,
+                                         d_type_string,
+                                         ldd,
+                                         compute_type_string,
+                                         algo,
+                                         solution_index,
+                                         rocblas_gemm_flags(flags));
                     }
 
                     if(layer_mode & rocblas_layer_mode_log_bench)
                     {
                         std::string alphas, betas;
-                        if(log_bench_alpha_beta_ex(compute_type, alpha, beta, alphas, betas)
-                           == rocblas_status_success)
-                        {
+                        (void)rocblas_internal_log_bench_alpha_beta_ex(
+                            compute_type, alpha, beta, alphas, betas);
 
-                            log_bench(handle,
-                                      ROCBLAS_API_BENCH " -f gemm_ex",
-                                      "--transposeA",
-                                      trans_a_letter,
-                                      "--transposeB",
-                                      trans_b_letter,
-                                      "-m",
-                                      m,
-                                      "-n",
-                                      n,
-                                      "-k",
-                                      k,
-                                      alphas,
-                                      "--a_type",
-                                      a_type_string,
-                                      "--lda",
-                                      lda,
-                                      "--b_type",
-                                      b_type_string,
-                                      "--ldb",
-                                      ldb,
-                                      betas,
-                                      "--c_type",
-                                      c_type_string,
-                                      "--ldc",
-                                      ldc,
-                                      "--d_type",
-                                      d_type_string,
-                                      "--ldd",
-                                      ldd,
-                                      "--compute_type",
-                                      compute_type_string,
-                                      "--algo",
-                                      algo,
-                                      "--solution_index",
-                                      solution_index,
-                                      "--flags",
-                                      flags);
-                        }
+                        logger.log_bench(handle,
+                                         ROCBLAS_API_BENCH " -f gemm_ex",
+                                         "--transposeA",
+                                         trans_a_letter,
+                                         "--transposeB",
+                                         trans_b_letter,
+                                         "-m",
+                                         m,
+                                         "-n",
+                                         n,
+                                         "-k",
+                                         k,
+                                         alphas,
+                                         "--a_type",
+                                         a_type_string,
+                                         "--lda",
+                                         lda,
+                                         "--b_type",
+                                         b_type_string,
+                                         "--ldb",
+                                         ldb,
+                                         betas,
+                                         "--c_type",
+                                         c_type_string,
+                                         "--ldc",
+                                         ldc,
+                                         "--d_type",
+                                         d_type_string,
+                                         "--ldd",
+                                         ldd,
+                                         "--compute_type",
+                                         compute_type_string,
+                                         "--algo",
+                                         algo,
+                                         "--solution_index",
+                                         solution_index,
+                                         "--flags",
+                                         flags);
                     }
 
                     if(layer_mode & rocblas_layer_mode_log_profile)
                     {
-                        log_profile(handle,
-                                    ROCBLAS_API_STR(rocblas_gemm_ex),
-                                    "a_type",
-                                    a_type_string,
-                                    "b_type",
-                                    b_type_string,
-                                    "c_type",
-                                    c_type_string,
-                                    "d_type",
-                                    d_type_string,
-                                    "compute_type",
-                                    compute_type_string,
-                                    "transA",
-                                    trans_a_letter,
-                                    "transB",
-                                    trans_b_letter,
-                                    "M",
-                                    m,
-                                    "N",
-                                    n,
-                                    "K",
-                                    k,
-                                    "alpha",
-                                    value_category(alpha, compute_type),
-                                    "lda",
-                                    lda,
-                                    "ldb",
-                                    ldb,
-                                    "beta",
-                                    value_category(beta, compute_type),
-                                    "ldc",
-                                    ldc,
-                                    "ldd",
-                                    ldd,
-                                    "algo",
-                                    algo,
-                                    "solution_index",
-                                    solution_index,
-                                    "flags",
-                                    rocblas_gemm_flags(flags));
+                        logger.log_profile(handle,
+                                           ROCBLAS_API_STR(rocblas_gemm_ex),
+                                           "a_type",
+                                           a_type_string,
+                                           "b_type",
+                                           b_type_string,
+                                           "c_type",
+                                           c_type_string,
+                                           "d_type",
+                                           d_type_string,
+                                           "compute_type",
+                                           compute_type_string,
+                                           "transA",
+                                           trans_a_letter,
+                                           "transB",
+                                           trans_b_letter,
+                                           "M",
+                                           m,
+                                           "N",
+                                           n,
+                                           "K",
+                                           k,
+                                           "alpha",
+                                           rocblas_internal_value_category(alpha, compute_type),
+                                           "lda",
+                                           lda,
+                                           "ldb",
+                                           ldb,
+                                           "beta",
+                                           rocblas_internal_value_category(beta, compute_type),
+                                           "ldc",
+                                           ldc,
+                                           "ldd",
+                                           ldd,
+                                           "algo",
+                                           algo,
+                                           "solution_index",
+                                           solution_index,
+                                           "flags",
+                                           rocblas_gemm_flags(flags));
                     }
                 }
             }
