@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -45,21 +45,23 @@ namespace
         if(!handle)
             return rocblas_status_invalid_handle;
 
+        rocblas_internal_logger logger;
+
         if(!handle->is_device_memory_size_query())
         {
             auto layer_mode = handle->layer_mode;
             if(layer_mode & rocblas_layer_mode_log_trace)
-                log_trace(handle,
-                          "rocblas_trsv_batched_ex",
-                          uplo,
-                          transA,
-                          diag,
-                          m,
-                          A,
-                          lda,
-                          B,
-                          incx,
-                          batch_count);
+                logger.log_trace(handle,
+                                 "rocblas_trsv_batched_ex",
+                                 uplo,
+                                 transA,
+                                 diag,
+                                 m,
+                                 A,
+                                 lda,
+                                 B,
+                                 incx,
+                                 batch_count);
 
             if(layer_mode & (rocblas_layer_mode_log_bench | rocblas_layer_mode_log_profile))
             {
@@ -70,42 +72,42 @@ namespace
                 if(layer_mode & rocblas_layer_mode_log_bench)
                 {
                     if(handle->pointer_mode == rocblas_pointer_mode_host)
-                        log_bench(handle,
-                                  "./rocblas-bench -f trsv_batched_ex -r",
-                                  rocblas_precision_string<T>,
-                                  "--uplo",
-                                  uplo_letter,
-                                  "--transposeA",
-                                  transA_letter,
-                                  "--diag",
-                                  diag_letter,
-                                  "-m",
-                                  m,
-                                  "--lda",
-                                  lda,
-                                  "--incx",
-                                  incx,
-                                  "--batch_count",
-                                  batch_count);
+                        logger.log_bench(handle,
+                                         "./rocblas-bench -f trsv_batched_ex -r",
+                                         rocblas_precision_string<T>,
+                                         "--uplo",
+                                         uplo_letter,
+                                         "--transposeA",
+                                         transA_letter,
+                                         "--diag",
+                                         diag_letter,
+                                         "-m",
+                                         m,
+                                         "--lda",
+                                         lda,
+                                         "--incx",
+                                         incx,
+                                         "--batch_count",
+                                         batch_count);
                 }
 
                 if(layer_mode & rocblas_layer_mode_log_profile)
-                    log_profile(handle,
-                                "rocblas_trsv_batched_ex",
-                                "uplo",
-                                uplo_letter,
-                                "transA",
-                                transA_letter,
-                                "diag",
-                                diag_letter,
-                                "M",
-                                m,
-                                "lda",
-                                lda,
-                                "incx",
-                                incx,
-                                "batch_count",
-                                batch_count);
+                    logger.log_profile(handle,
+                                       "rocblas_trsv_batched_ex",
+                                       "uplo",
+                                       uplo_letter,
+                                       "transA",
+                                       transA_letter,
+                                       "diag",
+                                       diag_letter,
+                                       "M",
+                                       m,
+                                       "lda",
+                                       lda,
+                                       "incx",
+                                       incx,
+                                       "batch_count",
+                                       batch_count);
             }
         }
 
