@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -82,9 +82,8 @@ enum class Processor : int
     gfx906  = 906,
     gfx908  = 908,
     gfx90a  = 910,
-    gfx940  = 940,
-    gfx941  = 941,
     gfx942  = 942,
+    gfx950  = 950,
     gfx1010 = 1010,
     gfx1011 = 1011,
     gfx1012 = 1012,
@@ -96,6 +95,7 @@ enum class Processor : int
     gfx1100 = 1100,
     gfx1101 = 1101,
     gfx1102 = 1102,
+    gfx1150 = 1150,
     gfx1151 = 1151,
     gfx1200 = 1200,
     gfx1201 = 1201
@@ -110,6 +110,10 @@ ROCBLAS_INTERNAL_EXPORT_NOINLINE rocblas_status
 ROCBLAS_INTERNAL_EXPORT_NOINLINE rocblas_status
     rocblas_internal_get_data_ptr(rocblas_handle handle, std::shared_ptr<void>& data_ptr);
 
+// cached device properties for handle device
+ROCBLAS_INTERNAL_EXPORT_NOINLINE const hipDeviceProp_t*
+                                       rocblas_internal_get_device_prop(rocblas_handle handle);
+
 /*******************************************************************************
  * \brief rocblas_handle is a structure holding the rocblas library context.
  * It must be initialized using rocblas_create_handle() and the returned handle mus
@@ -245,8 +249,14 @@ public:
         return archMajorMinor;
     }
 
+    int getWarpSize()
+    {
+        return mWarpSize;
+    }
+
     int getMaxSharedMemPerBlock()
     {
+        // TODO review sharedMemPerBlockOptin or use cached device_properties
         int max_mem = -1;
         THROW_IF_HIP_ERROR(hipDeviceGetAttribute(
             &max_mem, hipDeviceAttribute_t(hipDeviceAttributeMaxSharedMemoryPerBlock), device));
@@ -272,8 +282,8 @@ public:
 
     bool isDefaultHipBLASLtArch()
     {
-        int arch = getArch();
-        if(arch == 1200 || arch == 1201)
+        int gfx_arch = getArch();
+        if(gfx_arch == 1200 || gfx_arch == 1201 || gfx_arch == 950)
         {
             return true;
         }
@@ -286,34 +296,68 @@ public:
     }
 
     /*******************************************************************************
-     * This function determines whether or not to use the hipBLASLt backend based
-     * on the state of the environment variable and the current architecture.
-     *
+     * This function determines whether or not to try using the hipBLASLt backend
      * - If the enviornment variable is set, its value determines whether ot not to
-     *   use the hipBLASLt backend.
-     * - If the current architecture is supported, then the `prob_specific_useHipBLASLt`
-     *   input determines whether ot not to use the hipBLASLt backend.
-     * - Otherwise, the hipBLASLt backend is not used.
+     *   try the hipBLASLt backend.
+     * - Otherwise try when the current architecture is defaulted to hipBLASLt support
+     * - Always disable for any `batched` API when the current handle is in stream
+     *   capture mode (as hipblaslt batched dispatch does synchronous memory copies)
+     * - batched mode requires env variable opt in as has additional pointer copies
      ******************************************************************************/
-    auto useHipBLASLt(bool prob_specific_useHipBLASLt = true)
+    bool tryHipBLASLt(bool batched)
     {
+        bool status = false;
 
 #ifdef BUILD_WITH_HIPBLASLT
         if(hipblasltEnvVar < 0)
         {
             if(isDefaultHipBLASLtArch())
             {
-                return prob_specific_useHipBLASLt;
-            }
-            else
-            {
-                return false;
+                status = true;
             }
         }
-        return hipblasltEnvVar == 1;
-#else
-        return false;
+        else
+            status = hipblasltEnvVar == 1;
 #endif
+
+        if(status && batched)
+        {
+            static bool hipblasltEnvBatchedDisabled = [&] {
+                auto* env_var = getenv("ROCBLAS_USE_HIPBLASLT_BATCHED");
+                if(env_var)
+                {
+                    return strncmp(env_var, "0", 1) == 0;
+                }
+                return false;
+            }();
+
+            // only use for batched when explicitly enabled by env variable
+            if(!hipblasltEnvBatchedDisabled)
+                status = !is_stream_in_capture_mode();
+            else
+                status = false;
+        }
+
+        return status;
+    }
+
+    bool isHipBLASLtEnabled()
+    {
+        bool status = false;
+
+#ifdef BUILD_WITH_HIPBLASLT
+        if(hipblasltEnvVar < 0)
+        {
+            if(isDefaultHipBLASLtArch())
+            {
+                status = true;
+            }
+        }
+        else
+            status = hipblasltEnvVar == 1;
+#endif
+
+        return status;
     }
 
     inline int getDefaultDeviceMemorySize()
@@ -339,8 +383,8 @@ public:
     // default logging_mode is no logging
     rocblas_layer_mode layer_mode = rocblas_layer_mode_none;
 
-    // default atomics mode allows atomic operations
-    rocblas_atomics_mode atomics_mode = rocblas_atomics_allowed;
+    // default atomics mode does not allows atomic operations
+    rocblas_atomics_mode atomics_mode = rocblas_atomics_not_allowed;
 
     // Selects the benchmark library to be used for solution selection
     rocblas_performance_metric performance_metric = rocblas_default_performance_metric;
@@ -507,6 +551,10 @@ private:
     bool ROCBLAS_EXPORT device_allocator(size_t size);
 #endif
 
+public:
+    hipDeviceProp_t device_properties;
+
+private:
     // Device ID is created at handle creation time and remains in effect for the life of the handle.
     const int device;
 
@@ -515,10 +563,16 @@ private:
     int       archMajor;
     int       archMajorMinor;
 
+    const int mWarpSize;
+
     // hipBLASLt handle is created at handle creation time and remains in effect for the life of the handle.
     std::shared_ptr<hipblasLtHandle_t> hipblasLtHandle;
     int                                hipblasltEnvVar = -1;
 
+    // used in constructor initialization list
+    int       getActiveDevice();
+    Processor getActiveArch();
+
     // Opaque smart allocator class to perform device memory allocations
     // clang-format off
     class [[nodiscard]] _device_malloc : public rocblas_device_malloc_base
