@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2019-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2019-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,6 +34,7 @@
  * in this file, without referencing any Tensile-specific identifiers here.  *
  *****************************************************************************/
 
+#include "definitions.hpp"
 #include "handle.hpp"
 #include "tuple_helper.hpp"
 #include <atomic>
@@ -52,17 +53,27 @@ typedef enum
     MATCHES_TYPE,
 } rocblas_tensile_get_solution_option;
 
+inline constexpr bool rocblas_default_solution_index(rocblas_int solution_index)
+{
+    return solution_index == c_rocblas_default_solution || solution_index == -1;
+}
+
+inline constexpr bool rocblas_hipblaslt_index(rocblas_int solution_index)
+{
+    return solution_index > 0;
+}
+
+inline constexpr bool rocblas_tensile_index(rocblas_int solution_index)
+{
+    // coverted to negative 1 based as rocblas index
+    return solution_index < -c_rocblas_solutions_reserved;
+}
+
 /********************************************************************
  * RocblasContractionProblem captures the arguments for a GEMM-like *
  * contraction problem, to be passed to runContractionProblem.      *
  ********************************************************************/
-template <typename TiA,
-          typename To  = TiA,
-          typename Tc  = To,
-          typename TiB = TiA,
-          typename TcA = TiA,
-          typename TcB = TiA>
-//   <typename Ti, typename To = Ti, typename Tc = To>
+template <typename Ti, typename To = Ti, typename Tc = To>
 struct RocblasContractionProblem
 {
     rocblas_handle     handle;
@@ -80,19 +91,19 @@ struct RocblasContractionProblem
 
     const Tc* alpha;
 
-    const TiA*        A;
-    const TiA* const* batch_A;
-    size_t            row_stride_a;
-    size_t            col_stride_a;
-    size_t            batch_stride_a;
-    size_t            buffer_offset_a;
+    const Ti*        A;
+    const Ti* const* batch_A;
+    size_t           row_stride_a;
+    size_t           col_stride_a;
+    size_t           batch_stride_a;
+    size_t           buffer_offset_a;
 
-    const TiB*        B;
-    const TiB* const* batch_B;
-    size_t            row_stride_b;
-    size_t            col_stride_b;
-    size_t            batch_stride_b;
-    size_t            buffer_offset_b;
+    const Ti*        B;
+    const Ti* const* batch_B;
+    size_t           row_stride_b;
+    size_t           col_stride_b;
+    size_t           batch_stride_b;
+    size_t           buffer_offset_b;
 
     const Tc* beta;
 
@@ -113,72 +124,6 @@ struct RocblasContractionProblem
     size_t batch_count;
     bool   strided_batch;
 
-    // gemm
-    // gemm_strided_batched
-    RocblasContractionProblem(rocblas_handle     handle,
-                              rocblas_operation  trans_a,
-                              rocblas_operation  trans_b,
-                              rocblas_int        m,
-                              rocblas_int        n,
-                              rocblas_int        k,
-                              const Tc*          alpha,
-                              const TiA*         A,
-                              const TiA* const*  batch_A,
-                              rocblas_int        ld_a,
-                              rocblas_stride     batch_stride_a,
-                              rocblas_stride     offset_a,
-                              const TiB*         B,
-                              const TiB* const*  batch_B,
-                              rocblas_int        ld_b,
-                              rocblas_stride     batch_stride_b,
-                              rocblas_stride     offset_b,
-                              const Tc*          beta,
-                              To*                C,
-                              To* const*         batch_C,
-                              rocblas_int        ld_c,
-                              rocblas_stride     batch_stride_c,
-                              rocblas_stride     offset_c,
-                              rocblas_int        batch_count,
-                              bool               strided_batch,
-                              rocblas_gemm_flags flags)
-        : handle(handle)
-        , flags(flags)
-        , trans_a(trans_a)
-        , trans_b(trans_b)
-        , m(m)
-        , n(n)
-        , k(k)
-        , alpha(alpha)
-        , A(A)
-        , batch_A(batch_A)
-        , row_stride_a(1)
-        , col_stride_a(ld_a)
-        , batch_stride_a(batch_stride_a)
-        , buffer_offset_a(offset_a)
-        , B(B)
-        , batch_B(batch_B)
-        , row_stride_b(1)
-        , col_stride_b(ld_b)
-        , batch_stride_b(batch_stride_b)
-        , buffer_offset_b(offset_b)
-        , beta(beta)
-        , C(C)
-        , batch_C(batch_C)
-        , row_stride_c(1)
-        , col_stride_c(ld_c)
-        , batch_stride_c(batch_stride_c)
-        , buffer_offset_c(offset_c)
-        , D(C)
-        , batch_D(batch_C)
-        , row_stride_d(1)
-        , col_stride_d(ld_c)
-        , batch_stride_d(batch_stride_c)
-        , buffer_offset_d(offset_c)
-        , batch_count(batch_count)
-        , strided_batch(strided_batch)
-    {
-    }
-
     // gemm_ex
     // gemm_strided_batched_ex
     RocblasContractionProblem(rocblas_handle     handle,
@@ -188,13 +133,13 @@ struct RocblasContractionProblem
                               rocblas_int        n,
                               rocblas_int        k,
                               const Tc*          alpha,
-                              const TiA*         A,
-                              const TiA* const*  batch_A,
+                              const Ti*          A,
+                              const Ti* const*   batch_A,
                               rocblas_int        ld_a,
                               rocblas_stride     batch_stride_a,
                               rocblas_stride     offset_a,
-                              const TiB*         B,
-                              const TiB* const*  batch_B,
+                              const Ti*          B,
+                              const Ti* const*   batch_B,
                               rocblas_int        ld_b,
                               rocblas_stride     batch_stride_b,
                               rocblas_stride     offset_b,
@@ -258,12 +203,20 @@ struct RocblasContractionProblem
     {
         return tuple_helper::print_tuple_pairs(
             os,
-            std::make_tuple("a_type",
-                            rocblas_precision_string<TiA>,
+            std::make_tuple("a",
+                            prob.A,
+                            "a_type",
+                            rocblas_precision_string<Ti>,
+                            "b",
+                            prob.B,
                             "b_type",
-                            rocblas_precision_string<TiB>,
+                            rocblas_precision_string<Ti>,
+                            "c",
+                            prob.C,
                             "c_type",
                             rocblas_precision_string<To>,
+                            "d",
+                            prob.D,
                             "d_type",
                             rocblas_precision_string<To>,
                             "compute_type",
@@ -315,32 +268,35 @@ struct RocblasContractionProblem
     };
 };
 
+/*******************************************************************************
+ * This function determines whether or not to use the hipBLASLt backend based
+ * on problem specific conditions. This is passed on to the handle's useHipBLASLt
+ * function to consolidate with the architecture specific conditions and
+ * environment variable state.
+******************************************************************************/
+template <typename Ti, typename To, typename Tc>
+bool useHipBLASLt(const RocblasContractionProblem<Ti, To, Tc>& problem);
+
 /*******************************************************************************
  * runContractionProblem() solves a RocblasContractionProblem                  *
  *******************************************************************************/
-template <typename TiA,
-          typename To,
-          typename Tc,
-          typename TiB = TiA,
-          typename TcA = TiA,
-          typename TcB = TiA>
-// <typename Ti, typename To, typename Tc>
-rocblas_status
-    runContractionProblem(const RocblasContractionProblem<TiA, To, Tc, TiB, TcA, TcB>& problem,
-                          rocblas_gemm_algo algo           = rocblas_gemm_algo_standard,
-                          int32_t           solution_index = 0);
+template <typename Ti, typename To, typename Tc>
+rocblas_status runContractionProblem(const RocblasContractionProblem<Ti, To, Tc>& problem,
+                                     rocblas_gemm_algo algo           = rocblas_gemm_algo_standard,
+                                     int32_t           solution_index = 0);
 
-template <typename TiA,
-          typename To,
-          typename Tc,
-          typename TiB = TiA,
-          typename TcA = TiA,
-          typename TcB = TiA>
-//template <typename Ti, typename To, typename Tc>
-rocblas_status getAllSolutions(const RocblasContractionProblem<TiA, To, Tc, TiB, TcA, TcB>& prob,
-                               rocblas_tensile_get_solution_option                          option,
-                               rocblas_int* list_array,
-                               rocblas_int* list_size);
+template <typename Ti, typename To, typename Tc>
+rocblas_status getRocblasSolutions(const RocblasContractionProblem<Ti, To, Tc>& prob,
+                                   rocblas_tensile_get_solution_option          option,
+                                   rocblas_int*                                 list_array,
+                                   rocblas_int*                                 list_size,
+                                   rocblas_int                                  arrayIdx);
+
+template <typename Ti, typename To, typename Tc>
+rocblas_status getAllSolutions(const RocblasContractionProblem<Ti, To, Tc>& prob,
+                               rocblas_tensile_get_solution_option          option,
+                               rocblas_int*                                 list_array,
+                               rocblas_int*                                 list_size);
 
 /***********************************************************************************
  * Whether Tensile has been initialized for at least one device (used for testing) *
