@@ -58,6 +58,12 @@ def parse_args():
     general_opts.add_argument(      '--build_dir', type=str, required=False, default="build",
                         help='Specify path to configure & build process output directory.(optional, default: ./build)')
 
+    general_opts.add_argument(      '--ci_labels', type=str, required=False, default="",
+                        help='Semi-colon seperated list of labels that may modify build (optional, e.g. "gfx12;noTensile")')
+
+    general_opts.add_argument(      '--ci_gfx', type=str, required=False, default="",
+                        help='Semi-colon seperated list of gfx targets expected on test runs (optional, e.g. "gfx1030;gfx1201")')
+
     general_opts.add_argument(      '--cleanup', required=False, default=False, action='store_true',
                         help='Remove intermediary build files after build to reduce disk usage. (Linux only handled by install.sh)')
 
@@ -100,6 +106,9 @@ def parse_args():
     general_opts.add_argument('-j', '--jobs', type=int, required=False, default=0,
                         help='Specify number of parallel jobs to launch, affects memory usage (default: heuristic around logical core count)')
 
+    general_opts.add_argument('--ninja', required=False, default=False, action='store_true',
+                        help='Build using ninja generator (default: false on Linux, true on windows)')
+
     experimental_opts.add_argument('-k', '--relwithdebinfo', required=False, default=False, action='store_true',
                         help='Build in Release with Debug Info (optional, default: False)')
 
@@ -248,6 +257,9 @@ def get_compiler_jobs(env_var: str) -> int:
         return cjobs
 
 def get_env_compiler_parallelism() -> int:
+    # disable for now due to windows compiler issue and linux ignored warning
+    return 1
+
     # new and legacy env
     hip_clang_job_env = os.getenv('HIP_CLANG_NUM_PARALLEL_JOBS', "0")
 
@@ -317,11 +329,13 @@ def fatal(msg, code=1):
 def deps_cmd():
     if os.name == "nt":
         exe = f"python3 rdeps.py"
-        all_args = ""
+        stripped_args = ""
     else:
-        exe = f"./install.sh --rmake_invoked -d"
+        exe = f"./install.sh --rmake_invoked -d "
         all_args = ' '.join(sys.argv[1:])
-    return exe, all_args
+        stripped_args = all_args.split('--ci_labels')[0] # last args in CI
+        stripped_args = stripped_args.split('-a ')[0]
+    return exe, stripped_args
 
 
 def config_cmd():
@@ -349,6 +363,8 @@ def config_cmd():
     else:
         rocm_raw_path = os.getenv('ROCM_PATH', "/opt/rocm")
         rocm_path = rocm_raw_path
+        if (args.ninja):
+            cmake_platform_opts.append(f"-G Ninja")
         cmake_platform_opts.append(f"-DROCM_DIR:PATH={rocm_path} -DCPACK_PACKAGING_INSTALL_PREFIX={rocm_path}")
         cmake_platform_opts.append(f'-DCMAKE_INSTALL_PREFIX="rocblas-install"')
         toolchain = "toolchain-linux.cmake"
@@ -445,7 +461,7 @@ def config_cmd():
         else:
             fatal("Could not detect GPU as requested. Not continuing.")
     # not just for tensile
-    cmake_options.append(f'-DAMDGPU_TARGETS=\"{args.gpu_architecture}\"')
+    cmake_options.append(f'-DGPU_TARGETS=\"{args.gpu_architecture}\"')
 
     if not args.build_tensile:
         cmake_options.append(f"-DBUILD_WITH_TENSILE=OFF")
@@ -512,25 +528,48 @@ def make_cmd():
 
     make_options = []
 
-    if os.name == "nt":
+    if os.name == "nt" or args.ninja:
         # the CMAKE_BUILD_PARALLEL_LEVEL currently doesn't work for windows build, so using -j
         # make_executable = f"cmake.exe -DCMAKE_BUILD_PARALLEL_LEVEL=4 --build . " # ninja
-        make_executable = f"ninja.exe -j {args.jobs}"
+        exe_suffix = ".exe" if os.name == "nt" else ""
+        make_executable = f"ninja{exe_suffix} -j {args.jobs}"
         if args.verbose:
             make_options.append("--verbose")
-        make_options.append("all")  # for cmake "--target all" )
+        make_options.append("all")
         if args.install:
-            make_options.append("package install")  # for cmake "--target package --target install" )
+            make_options.append("package")
     else:
         make_executable = f"make -j{args.jobs}"
         if args.verbose:
             make_options.append("VERBOSE=1")
-        if not args.clients_only:
-            make_options.append("install")
+    if not args.clients_only:
+        make_options.append("install")
     cmd_opts = " ".join(make_options)
 
     return make_executable, cmd_opts
 
+def arg_into_list(arg) -> list:
+    arg = re.sub(r"['\"]|['\']",'', arg)
+    return arg.split(';')
+
+def label_modifiers(labels):
+    global args
+    processed = ["noTensile", "dependencies"]
+    overlap = [v for v in processed if v in labels]
+    if len(overlap):
+        if "noTensile" in overlap:
+            args.build_tensile = False
+        # TODO: Deferred
+        # if "dependencies" in overlap and os.name != "nt":
+        #     args.dependencies = True
+
+def gfx_modifiers(ci_gfx_list):
+    global args
+    if len(ci_gfx_list):
+        gfx = arg_into_list( args.gpu_architecture )
+        overlap = [v for v in ci_gfx_list if (v in gfx or "all" in gfx)]
+        if len(overlap):
+            args.gpu_architecture = ';'.join(overlap)
 
 def run_cmd(exe, opts):
     program = f"{exe} {opts}"
@@ -538,12 +577,16 @@ def run_cmd(exe, opts):
     proc = subprocess.run(program, check=True, stderr=subprocess.STDOUT, shell=True)
     return proc.returncode
 
-
 def main():
     global args
     os_detect()
     args = parse_args()
 
+    if args.ci_labels != "":
+        label_modifiers( arg_into_list(args.ci_labels) )
+    if args.ci_gfx != "":
+        gfx_modifiers( arg_into_list(args.ci_gfx) )
+
     if args.jobs == 0:
         args.jobs = jobs_heuristic()
     if os.name == "nt" and args.jobs > 61:
